function [x0,err] = bisect(xn,xp);
%
%  [x0,err] = bisect(xn,xp)
%
% This script will perform rootfinding by the
% bisection method.
%
% f(x) = 0
%
% inputs:
% xn = bracket where f(xn) < 0
% xp = bracket where f(xp) > 0
% f(x) entered in the function "funkeval" at the bottom of this file
%
% outputs:
% 
% x0 = converged solution
% err = relative error on x
%
% example usage:
%
% [x0,err] = bisect(0.1,1.0)
%
% Author:  David Keffer 
% original date: October 22, 1998
% last modified date: March 22, 2013
%

%
%  maximum number of iterations
%
maxit = 100;
%
%  acceptable tolerance
%
tol = 1.0e-6;
%
%  initialize error and counter
%
err = 100.0;
icount = 0;
%
%  evaluate function at brackets
%
fn = funkeval(xn);
fp = funkeval(xp);
%
%  iteration loop
%
while (err > tol & icount <= maxit)
   icount = icount + 1;
   xmid = (xn + xp)/2;
   fmid = funkeval(xmid);
   if (fmid > 0)
      fp = fmid;
      xp = xmid;
   else
      fn = fmid;
      xn = xmid;
   end
   err = abs((xp - xn)/xp);
   fprintf(1,'i = %i xn = %e xp = %e fn = %e fp = %e err = %e \n',icount, xn, xp, fn, fp, err);
end
%
%  update guess
%
x0 = xmid;
%
%  if you did not converge, let the user know
%
if (icount >= maxit)
   fprintf(1,'Sorry.  You did not converge in %i iterations.\n',maxit);
   fprintf(1,'The final value of x was %e \n', x0);
end

%
%  the function must be entered here
%
function f = funkeval(x)
f = x + log(x);
