function [x0,err] = succapp(x0);
%
%  [x0,err] = succapp(x0)
%
% This script will perform rootfinding by the
% successive approximations method.
%
% x = f(x)
%
% inputs:
% x0 = initial guess for x
% f(x) entered in the function "funkeval" at the bottom of this file
%
% outputs:
% 
% x0 = converged solution
% err = relative error on x
%
% example usage:
%
% [x0,err] = succapp(0.5)
%
% Author:  David Keffer 
% original date: October 22, 1998
% last modified date: March 22, 2013
%

%
%  maximum number of iterations
%
maxit = 100;
%
%  acceptable tolerance
%
tol = 1.0e-6;
%
%  initialize error and counter
%
err = 100.0;
icount = 0;
xold = x0;
%
%  iteration loop
%
while (err > tol & icount <= maxit)
   icount = icount + 1;
   xnew = funkeval(xold);
   if (icount > 1)
      err = abs((xnew - xold)/xnew);
   end
   fprintf(1,'icount = %i xnew = %e xold = %e err = %e \n',icount, xnew, xold, err);
   xold = xnew;
end
%
x0 = xnew;
%
%  print error message if not converged
%
if (icount >= maxit)
   % you ran out of iterations
   fprintf(1,'Sorry.  You did not converge in %i iterations.\n',maxit);
   fprintf(1,'The final value of x was %e \n', x0);
   fprintf(1,'Maybe you should try a better method because Successive Approximations is lame. \n');
end

%
%  the function must be entered here
%
function x = funkeval(x0)
x = exp(-x0);
